local NewGate = ...

-- Build the assignable function asset for the manual placed buildings
function registerAssignableFunction(_assetId)
    -- mandatory functions
    NewGate:registerAsset({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = NewGatePrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        registerFunctionHouse(NewGatePrefix, _assetId, "1"),
                        registerFunctionHouse(NewGatePrefix, _assetId, "2")
                }
    })
    -- optional functions if the mod "Cottage" is present
    if (_flagCottage) then
        NewGate:overrideAsset({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = NewGatePrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                    Action = "APPEND",
                    "BUILDING_FUNCTION_COTTAGE_BERRIES",
                    "BUILDING_FUNCTION_COTTAGE_WOOD",
                    "BUILDING_FUNCTION_FORESTER",
                    "BUILDING_FUNCTION_COTTAGE_FRUIT",
                    "BUILDING_FUNCTION_COTTAGE_BREAD",
                    "BUILDING_FUNCTION_COTTAGE_CHEESE",
                    "BUILDING_FUNCTION_COTTAGE_CLOTH",
                    "BUILDING_FUNCTION_COTTAGE_CLOTHES",
                    "BUILDING_FUNCTION_COTTAGE_FURNITURE",
                    "BUILDING_FUNCTION_HUNTERS_HUT",
                }
        })
        -- extra optional functions if the mod "Vegetable Farms" is present
        if (_flagVegetableFarms) then
            NewGate:overrideAsset({
            Id = NewGatePrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                    Action = "APPEND",
                    "BUILDING_FUNCTION_COTTAGE_BEAN",
                    "BUILDING_FUNCTION_COTTAGE_CABBAGE",
                }
            })
        end
    end
    -- register the assignable function asset
    NewGate:registerAsset({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = NewGatePrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = NewGatePrefix .. "_" .. _assetId .. "_FUNCTION_LIST"
    })
    return NewGatePrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION"
end

function registerHouse(_nameFbx, _nameAsset, _buildingZone) 
    -- Apply building asset processor
    NewGate:registerAssetProcessor("models/" .. _nameFbx .. ".fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    -- Register core prefab nodes
    NewGate:registerAssetId("models/" .. _nameFbx .. ".fbx/Prefab/NewGate/" .. _nameFbx .. "Part", NewGatePrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the water mill Core part
    NewGate:registerAsset({
	DataType = "BUILDING_PART",
	Id = NewGatePrefix .. "_" .. _nameAsset .. "_PART",
	Name = NewGatePrefix .. "_" .. _nameAsset .. "_NAME",
	Description = NewGatePrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "CORE",
	BuildingZone = _buildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = NewGatePrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*1 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = _NoSandbox*10 },
			{ Resource = "STONE", Quantity = _NoSandbox*10 },
		}}
	},
	AssetBuildingFunction = registerAssignableFunction(_nameAsset)
    })

-- Doors grounded
    NewGate:registerPrefabComponent("models/" .. _nameFbx .. ".fbx/Prefab/NewGate/" .. _nameFbx .. "Part/door1", {
	DataType = "COMP_GROUNDED"
    })
    NewGate:registerPrefabComponent("models/" .. _nameFbx .. ".fbx/Prefab/NewGate/" .. _nameFbx .. "Part/door2", {
	DataType = "COMP_GROUNDED"
    })
    -- For the stairs
    NewGate:configurePrefabFlagList("models/" .. _nameFbx .. ".fbx/Prefab/NewGate/" .. _nameFbx .. "Part/door1", { "PLATFORM" })
    NewGate:configurePrefabFlagList("models/" .. _nameFbx .. ".fbx/Prefab/NewGate/" .. _nameFbx .. "Part/door2", { "PLATFORM" })

end

registerHouse( "NewGate", "NEW_GATE",
    { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 6, 10 }, { -3, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 5, 5 }, { 6.5, -1.5 } ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } },
    }})
